#! /bin/sh
# ==================================================================== 
#
#   ECM: The Extensible Container Model
#   Copyright (C) 2004 THALES
#   Contact: openccm-ecm@objectweb.org
#
#   This library is free software; you can redistribute it and/or
#   modify it under the terms of the GNU Lesser General Public
#   License as published by the Free Software Foundation; either
#   version 2.1 of the License, or any later version.
#
#   This library is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#   Lesser General Public License for more details.
#
#   You should have received a copy of the GNU Lesser General Public
#   License along with this library; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
#   USA
#
#   Initial developer(s): Mathieu Vadet
#   Initial funding: IST COACH European Project (IST-2001-34445)
#                    http://www.ist-coach.org
#
# ==================================================================== 


#
#  Starts the demo
#

usage() {
    echo "usage: logdemo_start [options]"
    echo "Starts the demo."
    echo "--"
    echo "The following options are supported:"
    echo "  -h, --help       Print this message"
    echo "  -d, --debug      Activate debug mode (optional)"
    echo "  -w, --withlog    Activate log service (optional)"
    exit 1 ;
}

# parse arguments
debug=
withlog=

while [ -n "$1" ] ;
do
    if [ "$1" = "-h" ] || [ "$1" = "--help" ] ;
    then
        usage ;
    elif [ "$1" = "-d" ] || [ "$1" = "--debug" ] ;
    then 
        debug=--debug ;
    elif [ "$1" = "-w" ] || [ "$1" = "--withlog" ] ;
    then 
        withlog="t" ;
    fi ;

    shift ;
done

lszip=
suffix=

if [ -n "$withlog" ] ;
then
    echo "Starting Demo WITH log service"
    lszip="DCE:LogService=file:@ECM.install.zip.dir@/ccm_logservice.zip" 
    suffix="WithLog" ;
else 
    echo "Starting Demo WITHOUT log service" ;
fi

# start the NS
@ECM.install.bin.dir@/ns_start.sh $debug

# start the ExtCI with component zips
client_zip=DCE:Client${suffix}Impl=file:@ECM.install.zip.dir@/logdemo_client.zip
server_zip=DCE:Server${suffix}Impl=file:@ECM.install.zip.dir@/logdemo_server.zip
asyncserver_zip=DCE:AsyncServer${suffix}Impl=file:@ECM.install.zip.dir@/logdemo_asyncserver.zip

@ECM.install.bin.dir@/extci_start.sh $debug --autoload "$lszip,$client_zip,$server_zip,$asyncserver_zip"

# start the LogService if enabled
lsref=
services=
if [ -n "$withlog" ] ;
then
    @ECM.install.bin.dir@/logserver_start.sh $debug LogServer

    # obtain logservice IOR and set it as an initial ref
    lsref=`@ECM.install.bin.dir@/logserver_ior.sh $debug --url LogServer`
    args="-ORBInitRef LogService=$lsref $args"

    # services
    services="--services DCE:LogService"
fi


# start a CCM runtime with the client home
echo "Starting CCM runtime with the client home"
@ECM.install.bin.dir@/ccm_runtime_start.sh $debug --args "$args" --uuid DCE:Client${suffix}Impl $services ClientHome

# start a CCM runtime with the server home
echo "Starting CCM runtime with the server home"
@ECM.install.bin.dir@/ccm_runtime_start.sh $debug --args "$args" --uuid DCE:Server${suffix}Impl $services ServerHome

# start a CCM runtime with the async server home
echo "Starting CCM runtime with the async server home"
@ECM.install.bin.dir@/ccm_runtime_start.sh $debug --args "$args" --uuid DCE:AsyncServer${suffix}Impl $services AsyncServerHome


# start the main
entrypt=org.objectweb.ccm.logdemo.LogDemo.main
location=@ECM.install.lib.dir@/logdemo_main.jar
@ECM.install.bin.dir@/corba_runtime_start.sh $debug --entrypoint $entrypt --location $location LogDemoMain

echo "Demo started"
