// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p>The <tt>ComponentRuntime</tt> class provides the bootstrapping feature for a CCM home implemented
 **  using the system component based framework. It also relies on the fundamental CORBA runtime features.</p>
 **
 **  @see org.objectweb.corba.runtime.Runtime Runtime
 **/
public class ComponentRuntime
{
    static private String _class_name = "ComponentRuntime";
    static private SlotFactory _slot_factory;
    static private ContainerFactoryImpl _container_factory;
    // NOTE: stores the main orb instance
    static private org.omg.CORBA.ORB _orb;

    static {
        // create the slot factory
        _slot_factory = new SlotFactory();

        // create container factory
        _container_factory = (ContainerFactoryImpl)ContainerFactoryImpl.create_factory();

        // register component poa service factory
        String entrypt = "org.objectweb.ccm.runtime.ComponentPOAFactoryImpl.create_factory";
        getFFService().register_service_factory(ComponentPOAService.SERVICE_ID, null, entrypt);

        // add various valuetypes factories to the ORB service factory
        ORBFactory fact = (ORBFactory)getFFService().find_service_factory(ORBService.SERVICE_ID);

        // Cookie
        String tid = org.omg.Components.CookieHelper.id();
        org.omg.CORBA.portable.ValueFactory pfact = new CookieFactoryImpl();
        ValueFactory vfact = new ValueFactoryImpl(tid, pfact);
        fact.add_default_valuefactory(vfact);

        // NOTE: others factories are registered by the home servant as there're specific to its implementation
        // or by the deployment servant for the same reason

        _orb = null;
    }

    //
    //  public operations
    //

    static public FactoryFinderService
    getFFService()
    {
        return org.objectweb.corba.runtime.Runtime.getFFService();
    }

    static public RegistrationService
    getRegistrationService()
    {
        return org.objectweb.corba.runtime.Runtime.getRegistrationService();
    }

    static public MainThread
    getMainThread()
    {
        return org.objectweb.corba.runtime.Runtime.getMainThread();
    }

    static public SlotFactory
    getSlotFactory()
    {
        return _slot_factory;
    }

    static public ContainerFactoryImpl
    getContainerFactory()
    {
        return _container_factory;
    }

    static public org.omg.CORBA.ORB
    getORB()
    {
        return _orb;
    }

    static public org.omg.Components.CCMHome
    loadHome(ComponentRuntimeConfiguration config)
    {
        final String opname = "loadHome";

        // build home servant configuration 
        // build container service from configuration
        ContainerService conts = null;
        String poasid = ComponentPOAService.SERVICE_ID;
        if (config.orb_service!=null) {
            // case with pre-existing ORB service
            conts = _container_factory.asContainerService(config.service_uuids, config.dservice_refs, config.orb_service, poasid);
        }
        else {
            // case with no pre-existing ORB service and a pre-existing ExtCI
            conts = _container_factory.asContainerService(config.service_uuids, config.dservice_refs, config.initial_references, poasid);
        }

        // set as ORB singleton
        try {
            ORBServiceImpl orbimpl = (ORBServiceImpl)conts.orb_service();
            _orb = orbimpl.getORB();
        } catch (ClassCastException ex) {
            // ignore
        }

        org.omg.Components.CCMHome href = null;
        href = conts.component_poa_service().activate_home(config.implementation_uuid);

        // try to store in local file and in ns
        RegistrationService regs = getRegistrationService();
        // check if a IOR file is set
        String iorfile = config.runtime_iorfile;
        if (iorfile!=null) {
            // obtain file registration scheme
            FileRegistrationScheme filescheme = (FileRegistrationScheme)regs.get_scheme(FileRegistrationScheme.SCHEME_ID);
            filescheme.write_ior(iorfile, href, conts.orb_service());
        }

        // obtain ns name from properties (always set)
        String insname = config.runtime_id;
        INSRegistrationScheme insscheme = (INSRegistrationScheme)regs.get_scheme(INSRegistrationScheme.SCHEME_ID);
        insscheme.bind(insname, href, conts.orb_service());

        // 
        return href;
    }
}
