// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p></p>
 **/
public class HomeLocalReceptaclesImpl
{
    // receptalces
    static private String _class_name = "HomeLocalReceptaclesImpl";
    private java.util.Hashtable _name2cnxs;
    private CallInterceptorFactory _factory;

    // empty constructor
    public
    HomeLocalReceptaclesImpl()
    {
        // receptalces
        _name2cnxs = null;
        _factory = null;
    }

    // default constructor
    public
    HomeLocalReceptaclesImpl(CallInterceptorFactory ifact)
    {
        // receptalces
        _name2cnxs = new java.util.Hashtable();
        _factory = ifact;
    }

    //
    //  public operations (for LocalReceptacleImpl class)
    //

    final public org.omg.Components.Cookie
    connect(byte[] cid, String name, org.omg.CORBA.Object obj)
    {
        // obtain local connection list
        String rname = new String(cid)+":"+name;
        java.util.ArrayList cnxs = (java.util.ArrayList)_name2cnxs.get(rname);
        if (cnxs==null) {
            cnxs = new java.util.ArrayList();
            _name2cnxs.put(rname, cnxs);
        }

        // create cookie
        CookieImpl lck = new CookieImpl(name);

        // create stub interceptor if available
        if (_factory!=null) {
            org.omg.CORBA.Object inter = _factory.createStubInterceptor(name, obj);
            // add local connection (replace real stub by stub interceptor)
            LocalConnectionImpl cnx = new LocalConnectionImpl(lck, inter);
            cnxs.add(cnx);
        } else {
            // add local connection
            LocalConnectionImpl cnx = new LocalConnectionImpl(lck, obj);
            cnxs.add(cnx);
        }

        // 
        return lck;
    }

    final public org.omg.CORBA.Object
    disconnect(byte[] cid, org.omg.Components.Cookie ck)
    throws org.omg.Components.InvalidSubscription
    {
        // NOTE: ck must be a CookieImpl
        if (!(ck instanceof CookieImpl)) {
            // NOTE: is this the right exception ? there's no other one ...
            throw new org.omg.Components.InvalidSubscription();
        }

        // get name from cookie
        CookieImpl lck = (CookieImpl)ck;
        String name = lck.getName();
        String rname = new String(cid)+":"+name;

        // get list of connection
        java.util.ArrayList cnxs = (java.util.ArrayList)_name2cnxs.get(rname);

        if (cnxs==null) {
            throw new org.omg.Components.InvalidSubscription();
        }

        // remove
        org.omg.CORBA.Object res = null;
        org.omg.Components.LocalConnection lcnx = null;
        for (int i=0;i<cnxs.size();i++) {
            lcnx = (org.omg.Components.LocalConnection)cnxs.get(i);
            if (lcnx.ck().equals(ck)) {
                res = (org.omg.CORBA.Object)cnxs.remove(i);
                break;
            }
        }

        // check if removal occured
        if (res==null) {
            throw new org.omg.Components.InvalidSubscription();
        }
        
        return res;
    }

    final public org.omg.Components.LocalConnection[]
    get_connections(byte[] cid, String name)
    throws org.omg.Components.InvalidName
    {
        // get list of connection
        String rname = new String(cid)+":"+name;
        java.util.ArrayList cnxs = (java.util.ArrayList)_name2cnxs.get(rname);

        if (cnxs==null) {
            throw new org.omg.Components.InvalidName();
        }

        return (org.omg.Components.LocalConnection[])cnxs.toArray(new org.omg.Components.LocalConnection[0]);
    }
}
