#! /bin/sh
# ==================================================================== 
#
#   ECM: The Extensible Container Model
#   Copyright (C) 2004 THALES
#   Contact: openccm-ecm@objectweb.org
#
#   This library is free software; you can redistribute it and/or
#   modify it under the terms of the GNU Lesser General Public
#   License as published by the Free Software Foundation; either
#   version 2.1 of the License, or any later version.
#
#   This library is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#   Lesser General Public License for more details.
#
#   You should have received a copy of the GNU Lesser General Public
#   License along with this library; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
#   USA
#
#   Initial developer(s): Mathieu Vadet
#   Initial funding: IST COACH European Project (IST-2001-34445)
#                    http://www.ist-coach.org
#
# ==================================================================== 


#
#  Displays the IOR of a started CCM Runtime
#

usage() {
    echo "usage: ccm_runtime_ior.sh [options]"
    echo "Display the IOR of a CCM runtime."
    echo "--"
    echo "The following options are supported:"
    echo "  -h, --help     Print this message"
    echo "  -d, --debug    Activate debug mode (optional)"
    echo "  -u, --url      Display an URL instead of the IOR (using a file: scheme) (optional)"
    echo "  name           The logical name of the CCM runtime, no default value (mandatory)"
    exit 1;
}

# parse arguments
name=
debug=
url=

while [ -n "$1" ] ;
do
    if [ "$1" = "-h" ] || [ "$1" = "--help" ] ;
    then
        usage ;
    elif [ "$1" = "-d" ] || [ "$1" = "--debug" ] ;
    then 
        debug=t ;
    elif [ "$1" = "-u" ] || [ "$1" = "--url" ] ;
    then 
        url=t ;
    else
        name=$1
    fi ;

    shift ;
done

# check if the CCM runtime is started
if [ ! -f $CCM_RUNTIME_REPOSITORY/$name.pid ] ;
then
    echo "ERROR: No CCM runtime with logical name: $name is started."
    exit 1 ;
fi

# display
if [ -n "$url" ] ;
then
    # echo as URL
    echo "file:$CCM_RUNTIME_REPOSITORY/$name.ior"
else
    # echo IOR directly
    cat $CCM_RUNTIME_REPOSITORY/$name.ior
fi
