#! /bin/sh
# ==================================================================== 
#
#   ECM: The Extensible Container Model
#   Copyright (C) 2004 THALES
#   Contact: openccm-ecm@objectweb.org
#
#   This library is free software; you can redistribute it and/or
#   modify it under the terms of the GNU Lesser General Public
#   License as published by the Free Software Foundation; either
#   version 2.1 of the License, or any later version.
#
#   This library is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#   Lesser General Public License for more details.
#
#   You should have received a copy of the GNU Lesser General Public
#   License along with this library; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
#   USA
#
#   Initial developer(s): Mathieu Vadet
#   Initial funding: IST COACH European Project (IST-2001-34445)
#                    http://www.ist-coach.org
#
# ==================================================================== 


#
#  Starts a CCM runtime
#

usage() {
    echo "usage: ccm_runtime_start.sh [options]"
    echo "Starts a CCM runtime."
    echo "--"
    echo "The following options are supported:"
    echo "  -h, --help                         Print this message"
    echo "  -d, --debug                        Activate debug mode (optional)"
    echo "  --uuid uuid                        UUID of the component implementation (mandatory)"
    echo "  --services    \"uuid1 ... uuidn\"    UUID list of the services implementations to be installed (optional)"
    echo "  --ns nsior                         NS to use for registrations, default to NS_at_hostname NS (optional)"
    echo "  --extci extciior                   ExtCI to use for implementation requests, default to ExtCI_at_hostname ExtCI (optional)"
    echo "  --jvmargs     \"arg1 ... argn\"      Set arg1 ... argn as JVM arguments (optional)"
    echo "  --args        \"arg1 ... argn\"      Set arg1 ... argn as launcher arguments (optional)"
    echo "  name                               The logical name of the CCM runtime, no default value (mandatory)"
    exit 1;
}

# parse args
debug=
uuid=
services=
nsior=
extciior=
args=
jvmargs=
name=

while [ -n "$1" ] ;
do
    if [ "$1" = "-h" ] || [ "$1" = "--help" ];
    then
        usage ;
    elif [ "$1" = "-d" ] || [ "$1" = "--debug" ] ;
    then
        debug=--debug ;
    elif [ "$1" = "--uuid" ] ;
    then
        uuid=$2
        shift ;
    elif [ "$1" = "--services" ] ;
    then
        services=$2
        shift ;
    elif [ "$1" = "--ns" ] ;
    then
        nsior=$2
        shift ;
    elif [ "$1" = "--extci" ] ;
    then
        extciior=$2
        shift ;
    elif [ "$1" = "--args" ] ;
    then
        args=$2
        shift ;
    elif [ "$1" = "--jvmargs" ] ;
    then
        jvmargs=$2
        shift ;
    else
        name=$1 ;
    fi

    shift ;
done

# check if name is set
if [ -z "$name" ] ;
then
    echo "ERROR: logical name of the CCM runtime is missing."
    exit 1;
fi

# check if UUID is set
if [ -z "$uuid" ] ;
then
    echo "ERROR: UUID is missing."
    exit 1 ;
fi

# Check if the CCM Runtime is started.
if [ -f $CCM_RUNTIME_REPOSITORY/$name.pid ] ;
then
    if [ -n "$debug" ] ;
    then
        echo "WARNING: The CCM runtime with logical name: $name is already started."
    fi ;
fi

# check if a NS is provided
if [ -z "$nsior" ] ;
then
    # use the default NS
    nsior=`@ECM.install.bin.dir@/ns_ior.sh $debug --url`
fi

# check if an ExtCI is provided
if [ -z "$extciior" ] ;
then
    # use the default ExtCI
    extciior=`@ECM.install.bin.dir@/extci_ior.sh $debug --url`
fi

# start the CCM Runtime
if [ -n "$debug" ] ;
then
    echo "The CCM Runtime $name will be started ..."
fi

# add debug if needed
if [ -n "$debug" ] ;
then
    jvmargs="-Ddebug=true $jvmargs"
else
    jvmargs="-Ddebug=false $jvmargs"
fi

# add services if needed
if [ -n "$services" ] ;
then
    args="-ServiceUUIDs $services $args"
fi

# add UUID, and runtime id
args="-ComponentUUID $uuid $args"
args="-RuntimeId $name $args"

# add IOR file
args="-RuntimeIORFile $CCM_RUNTIME_REPOSITORY/$name.ior $args"

args="--runid ccm_runtime -ORBInitRef NameService=$nsior -ORBInitRef ExtComponentInstallation=$extciior $args"
@OpenCCM.install.bin.dir@/launcher.sh fork "$jvmargs" "$args @ECM.install.launcher.dir@/ccm_runtime.xml" $CCM_RUNTIME_REPOSITORY/$name.output $CCM_RUNTIME_REPOSITORY/$name.pid

if [ -n "$debug" ] ;
then
    echo "The CCM Runtime $name is started."
fi
