@echo off
REM ==================================================================== 
REM
REM   ECM: The Extensible Container Model
REM   Copyright (C) 2004 THALES
REM   Contact: openccm-ecm@objectweb.org
REM
REM   This library is free software; you can redistribute it and/or
REM   modify it under the terms of the GNU Lesser General Public
REM   License as published by the Free Software Foundation; either
REM   version 2.1 of the License, or any later version.
REM
REM   This library is distributed in the hope that it will be useful,
REM   but WITHOUT ANY WARRANTY; without even the implied warranty of
REM   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
REM   Lesser General Public License for more details.
REM
REM   You should have received a copy of the GNU Lesser General Public
REM   License along with this library; if not, write to the Free Software
REM   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
REM   USA
REM
REM   Initial developer(s): Mathieu Vadet
REM   Initial funding: IST COACH European Project (IST-2001-34445)
REM                    http://www.ist-coach.org
REM
REM ==================================================================== 


REM
REM  Starts a CCM runtime
REM

setlocal

goto begin

:usage
    echo usage: ccm_runtime_start.bat [options]
    echo Starts a CCM runtime.
    echo --
    echo The following options are supported:
    echo   /h, /help                         Print this message
    echo   /debug                            Activate debug mode (optional)
    echo   /uuid uuid                        UUID of the component implementation (mandatory)
    echo   /services    "uuid1 ... uuidn"    UUID list of the services implementations to be installed (optional)
    echo   /ns nsior                         NS to use for registrations, default to "NS_at_hostname" NS (optional)
    echo   /extci extciior                   ExtCI to use for implementation requests, default to "ExtCI_at_hostname" ExtCI (optional)
    echo   /jvmargs     "arg1 ... argn"      Set arg1 ... argn as JVM arguments (optional)
    echo   /args        "arg1 ... argn"      Set arg1 ... argn as launcher arguments (optional)
    echo   name                              The logical name of the CCM runtime, no default value (mandatory)
    exit /B 1

:begin
set debug=
set uuid=
set services=
set nsior=
set extciior=
set args=
set jvmargs=
set name=

:parse_args
if not "%1"=="" (
    if "%1"=="/h" (
        goto usage
    ) else if "%1"=="/help" (
        goto usage
    ) else if "%1"=="/debug" (
        set debug=/debug
    ) else if "%1"=="/uuid" (
        set uuid=%2
        shift
    ) else if "%1"=="/services" (
        set services=%2
        shift
    ) else if "%1"=="/ns" (
        set nsior=%2
        shift
    ) else if "%1"=="/extci" (
        set extciior=%2
        shift
    ) else if "%1"=="/args" (
        set args=%2
        shift
    ) else if "%1"=="/jvmargs" (
        set jvmargs=%2
        shift
    ) else (
        set name=%1
    )

    shift
    goto parse_args
)


REM check if name is set
if not defined name (
    echo ERROR: logical name of the CCM runtime is missing.
    exit /B 1
)

REM check if UUID is set
if not defined uuid (
    echo ERROR: UUID is missing.
    exit /B 1
)

REM Check if the CCM Runtime is started.
if exist %CCM_RUNTIME_REPOSITORY%\%name%.pid (
    if defined debug (
        echo WARNING: The CCM runtime with logical name: %name% is already started.
    )
)

REM check if a NS is provided
if not defined nsior (
    REM use the default NS
    call @ECM.install.bin.dir@\ns_ior.bat %debug% /url > %TEMP%\ns_ior.tmp
    REM check if the IOR was correctly retrieved
    if ERRORLEVEL 1 exit /B 1

    for /f %%i in (%TEMP%\ns_ior.tmp) do (
        set nsior=%%i
    )
    del %TEMP%\ns_ior.tmp 2> nul
)

REM check if an ExtCI is provided
if not defined extciior (
    REM use the default ExtCI
    call @ECM.install.bin.dir@\extci_ior.bat %debug% /url > %TEMP%\extci_ior.tmp
    REM check if the IOR was correctly retrieved
    if ERRORLEVEL 1 exit /B 1

    for /f %%i in (%TEMP%\extci_ior.tmp) do (
        set extciior=%%i
    )
    del %TEMP%\extci_ior.tmp 2> nul
)

REM start the CCM Runtime
if defined debug (
    echo The CCM Runtime %name% will be started ...
)

REM add debug if needed
if defined debug (
    set jvmargs=-Ddebug=true %jvmargs%
) else (
    set jvmargs=-Ddebug=false %jvmargs%
)

REM add services if needed
if defined services (
    set args=-ServiceUUIDs %services% %args%
)

REM add UUID, and runtime id
set args=-ComponentUUID %uuid% %args%
set args=-RuntimeId %name% %args%

REM add IOR file
set args=-RuntimeIORFile %CCM_RUNTIME_REPOSITORY%\%name%.ior %args%

set args=--runid ccm_runtime -ORBInitRef NameService=%nsior% -ORBInitRef ExtComponentInstallation=%extciior% %args%
call @OpenCCM.install.bin.dir@\launcher.bat fork "%jvmargs:"=%" "%args:"=% @ECM.install.launcher.dir@\ccm_runtime.xml" %CCM_RUNTIME_REPOSITORY%\%name%.output %CCM_RUNTIME_REPOSITORY%\%name%.pid

if defined debug (
    echo The CCM Runtime %name% is started.
)

:eof
