@echo off
REM ==================================================================== 
REM
REM   ECM: The Extensible Container Model
REM   Copyright (C) 2004 THALES
REM   Contact: openccm-ecm@objectweb.org
REM
REM   This library is free software; you can redistribute it and/or
REM   modify it under the terms of the GNU Lesser General Public
REM   License as published by the Free Software Foundation; either
REM   version 2.1 of the License, or any later version.
REM
REM   This library is distributed in the hope that it will be useful,
REM   but WITHOUT ANY WARRANTY; without even the implied warranty of
REM   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
REM   Lesser General Public License for more details.
REM
REM   You should have received a copy of the GNU Lesser General Public
REM   License along with this library; if not, write to the Free Software
REM   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
REM   USA
REM
REM   Initial developer(s): Mathieu Vadet
REM   Initial funding: IST COACH European Project (IST-2001-34445)
REM                    http://www.ist-coach.org
REM
REM ==================================================================== 


REM
REM  Starts an Extended Component Installation object
REM

setlocal

goto begin

:usage
    echo usage: extci_start.bat [options]
    echo Starts a CCM ExtendedComponentInstallation.
    echo --
    echo The following options are supported:
    echo   /h, /help                         Print this message
    echo   /debug                            Activate debug mode (optional)
    echo   /ns nsior                         NS to use for registrations, default to NS_at_hostname NS (optional)
    echo   /autoload "uuid=loc,uuid=loc*"    List of component archives (separated by commas) to be loaded (optional)
    echo   name                              The logical name of the ExtCI, ExtCI_at_hostname by default (optional)
    exit /B 1

:begin
set autoload=
set debug=
set name=
set ns=
set args=
set jvmargs=

:parse_args
if not "%1"=="" (
    if "%1"=="/h" (
        goto usage
    ) else if "%1"=="/help" (
        goto usage
    ) else if "%1"=="/debug" (
        set debug=/debug
    ) else if "%1"=="/ns" (
        set ns=/ns %2
        shift
    ) else if "%1"=="/autoload" (
        set autoload=%2
        shift
    ) else (
        set name=%1
    ) 

    shift
    goto parse_args
)

REM check if name is set
if not defined name (
    if defined debug (
        echo WARNING: Will use default name for CCM ExtendedComponentInstallation.
    )

    hostname > %TEMP%\hostname.tmp
    for /f %%i in (%TEMP%\hostname.tmp) do (
        set name=ExtCI_at_%%i
    )
    del %TEMP%\hostname.tmp 2> nul
)

REM create and set zip cache
set zip_cache=%CCM_RUNTIME_REPOSITORY%\%name%
mkdir %zip_cache%
set jvmargs=-Dzip.cache=%zip_cache% %jvmargs%
set args=-ZipCache %zip_cache% %args%

REM set DTD location
set jvmargs=-Ddtd.location=@ECM.install.dtd.dir@ %jvmargs%
set args=-DTDLocation=@ECM.install.dtd.dir@ %args%

if defined autoload (
    set jvmargs=-Darchives.autoload=%autoload% %jvmargs%
    set args=-ArchivesAutoload %autoload% %args%
)

REM set code location and entrypt
set location=@ECM.install.lib.dir@\ccm_runtime_extci.jar
set entrypt=org.objectweb.ccm.runtime.ExtComponentInstallationImpl.create_servant

REM start
if defined debug (
    echo INFO: Starting CCM ExtCI %name% ...
)

call @ECM.install.bin.dir@\corba_runtime_start.bat /jvmargs "%jvmargs:"=%" /args "%args:"=%" /location %location% /entrypoint %entrypt% %ns% %debug% %name%

if defined debug (
    echo INFO: The CCM ExtCI %name% is started.
)

:eof
