@echo off
REM ==================================================================== 
REM
REM   ECM: The Extensible Container Model
REM   Copyright (C) 2004 THALES
REM   Contact: openccm-ecm@objectweb.org
REM
REM   This library is free software; you can redistribute it and/or
REM   modify it under the terms of the GNU Lesser General Public
REM   License as published by the Free Software Foundation; either
REM   version 2.1 of the License, or any later version.
REM
REM   This library is distributed in the hope that it will be useful,
REM   but WITHOUT ANY WARRANTY; without even the implied warranty of
REM   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
REM   Lesser General Public License for more details.
REM
REM   You should have received a copy of the GNU Lesser General Public
REM   License along with this library; if not, write to the Free Software
REM   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
REM   USA
REM
REM   Initial developer(s): Mathieu Vadet
REM   Initial funding: IST COACH European Project (IST-2001-34445)
REM                    http://www.ist-coach.org
REM
REM ==================================================================== 


REM
REM  Displays the IOR of a started CORBA Runtime
REM

setlocal

goto begin

:usage
    echo usage: corba_runtime_ior.bat [options]
    echo Display the IOR of a CORBA runtime.
    echo --
    echo The following options are supported:
    echo   /h, /help    Print this message
    echo   /debug       Activate debug mode (optional)
    echo   /url         Display an URL instead of the IOR (using a file: scheme) (optional)
    echo   name         The logical name of the CORBA runtime, no default value (mandatory)
    exit /B 1

:begin
set name=
set debug=
set url=

:parse_args
if not "%1"=="" (
    if "%1"=="/h" (
        goto usage
    ) else if "%1"=="/help" (
        goto usage
    ) else if "%1"=="/debug" (
        set debug=t
    ) else if "%1"=="/url" (
        set url=t
    ) else (
        set name=%1
    )

    shift
    goto parse_args
)

REM check if name is set
if not defined name (
    echo ERROR: logical name of the CORBA runtime is missing.
    exit /B 1
)

REM check if the CORBA runtime is started
if not exist %CORBA_RUNTIME_REPOSITORY%\%name%.pid (
    echo ERROR: No CORBA runtime with logical name: %name% is started.
    exit /B 1
)

REM display
if defined url (
    REM display as file: URL
    REM we first echo to a file and then display the file content as the echo command
    REM does not modify the ERRORLEVEL variable (which may be used by the caller of this
    REM script to know if something went wrong)
    echo file:%CORBA_RUNTIME_REPOSITORY%\%name%.ior > %TEMP%\ior.tmp
    type %TEMP%\ior.tmp
    del %TEMP%\ior.tmp 2> nul
) else (
    REM display IOR
    type %CORBA_RUNTIME_REPOSITORY%\%name%.ior
)


:eof