@echo off
REM ==================================================================== 
REM
REM   ECM: The Extensible Container Model
REM   Copyright (C) 2004 THALES
REM   Contact: openccm-ecm@objectweb.org
REM
REM   This library is free software; you can redistribute it and/or
REM   modify it under the terms of the GNU Lesser General Public
REM   License as published by the Free Software Foundation; either
REM   version 2.1 of the License, or any later version.
REM
REM   This library is distributed in the hope that it will be useful,
REM   but WITHOUT ANY WARRANTY; without even the implied warranty of
REM   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
REM   Lesser General Public License for more details.
REM
REM   You should have received a copy of the GNU Lesser General Public
REM   License along with this library; if not, write to the Free Software
REM   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
REM   USA
REM
REM   Initial developer(s): Mathieu Vadet
REM   Initial funding: IST COACH European Project (IST-2001-34445)
REM                    http://www.ist-coach.org
REM
REM ==================================================================== 


REM
REM  Starts a CORBA runtime
REM

setlocal

goto begin

:usage
    echo usage: corba_runtime_start [options]
    echo Starts a CORBA runtime.
    echo --
    echo The following options are supported:
    echo   /h, /help                      Print this message
    echo   /debug                         Activate debug mode (optional)
    echo   /location   location           Set JAR location (optional)
    echo   /entrypoint entrypoint         Set servant entrypoint (mandatory)
    echo   /ns nsior                      NS to use for registrations, default to "NS_at_hostname" NS (optional)
    echo   /jvmargs    "arg1 ... argn"    Set arg1 ... argn as JVM arguments (optional)
    echo   /args       "arg1 ... argn"    Set arg1 ... argn as launcher arguments (optional) 
    echo   name                           The logical name of the CORBA runtime, no default value (mandatory)
    exit /B 1

:begin
set debug=
set location=
set entrypoint=
set nsior=
set args=
set jvmargs=
set name=

:parse_args
if not "%1"=="" (
    if "%1"=="/h" (
        goto usage
    ) else if "%1"=="/help" (
        goto usage
    ) else if "%1"=="/debug" (
        set debug=/debug
    ) else if "%1"=="/location" (
        set location=%2
        shift 
    ) else if "%1"=="/entrypoint" (
        set entrypoint=%2
        shift
    ) else if "%1"=="/ns" (
        set nsior=%2
        shift
    ) else if "%1"=="/args" (
        set args=%2
        shift
    ) else if "%1"=="/jvmargs" (
        set jvmargs=%2
        shift
    ) else (
        set name=%1
    )

    shift
    goto parse_args
)

REM check if name is set
if not defined name (
    echo ERROR: logical name of the CORBA runtime is missing.
    exit /B 1
)

REM check if entrypoint is set
if not defined entrypoint (
    echo ERROR: entrypoint of the servant is missing.
    exit /B 1
)

REM Check if the CORBA Runtime is started.
if exist %CORBA_RUNTIME_REPOSITORY%\%name%.pid (
    if defined debug (
        echo WARNING: The CORBA runtime with logical name: %name% is already started.
    )
)

REM check if a NS is provided
if not defined nsior (
    REM use a local NS
    call @ECM.install.bin.dir@\ns_ior.bat %debug% /url  > %TEMP%\nsior.tmp
    REM check if the IOR was correctly retrieved
    if ERRORLEVEL 1 exit /B 1

    for /f %%i in (%TEMP%\nsior.tmp) do (
        set nsior=%%i
    )
    del %TEMP%\nsior.tmp 2> nul
)

REM starts the CORBA Runtime
if defined debug (
    echo INFO: The CORBA Runtime %name% will be started ...
)

REM add debug if needed
if defined debug (
    set jvmargs=-Ddebug=true %jvmargs%
    set args=-DebugOn
) else (
    set jvmargs=-Ddebug=false %jvmargs%
    set args=-DebugOff
)

REM add archive location if needed
if defined location (
    set jvmargs=-Darchive.location=%location% %jvmargs%
    set args=-ArchiveLocation %location% %args%
)

REM add entrypoint and runtime id
set jvmargs=-Darchive.entrypoint=%entrypoint% %jvmargs%
set jvmargs=-Druntime.id=%name% %jvmargs%
set args=-ArchiveEntrypoint %entrypoint% %args%
set args=-RuntimeId %name% %args%

REM add IOR file
set jvmargs=-Druntime.iorfile=%CORBA_RUNTIME_REPOSITORY%\%name%.ior %jvmargs%

set args=--runid corba_runtime -ORBInitRef NameService=%nsior% %args%
call @OpenCCM.install.bin.dir@\launcher.bat fork "%jvmargs:"=%" "%args:"=% @ECM.install.launcher.dir@\corba_runtime.xml" %CORBA_RUNTIME_REPOSITORY%\%name%.output %CORBA_RUNTIME_REPOSITORY%\%name%.pid

if defined debug (
    echo INFO: The CORBA Runtime %name% is started.
)

:eof
