#! /bin/sh
# ==================================================================== 
#
#   ECM: The Extensible Container Model
#   Copyright (C) 2004 THALES
#   Contact: openccm-ecm@objectweb.org
#
#   This library is free software; you can redistribute it and/or
#   modify it under the terms of the GNU Lesser General Public
#   License as published by the Free Software Foundation; either
#   version 2.1 of the License, or any later version.
#
#   This library is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
#   Lesser General Public License for more details.
#
#   You should have received a copy of the GNU Lesser General Public
#   License along with this library; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
#   USA
#
#   Initial developer(s): Mathieu Vadet
#   Initial funding: IST COACH European Project (IST-2001-34445)
#                    http://www.ist-coach.org
#
# ==================================================================== 


#
#  Starts a CORBA LogServer
#

usage() {
    echo "usage: logserver_start.sh [options]"
    echo "Starts a CORBA LogServer."
    echo "--"
    echo "The following options are supported:"
    echo "  -h, --help     Print this message"
    echo "  -d, --debug    Activate debug mode (optional)"
    echo "  --ns nsior     NS to use for registrations, default to NS_at_hostname NS (optional)"
    echo "  name           The logical name of the LogServer, LogServer_at_hostname by default (optional)"
    exit 1;
}


# parse arguments
debug=
name=
ns=

while [ -n "$1" ] ;
do
    if [ "$1" = "-h" ] || [ "$1" = "--help" ];
    then
        usage ;
    elif [ "$1" = "-d" ] || [ "$1" = "--debug" ] ;
    then
        debug=--debug ;
    elif [ "$1" = "--ns" ] ;
    then
        ns=--ns $2
        shift ;
    else
        name=$1 ;
    fi ;

    shift ;
done

# check if name is set
if [ -z "$name" ] ;
then
    if [ -n "$debug" ] ;
    then
        echo "WARNING: Will use default name for CORBA LogServer."
    fi ;

    hostname=`hostname`
    name=LogServer_at_$hostname ;
fi

# set code location and entrypt
location=@ECM.install.lib.dir@/corba_logservice_server.jar
entrypt=org.objectweb.corba.logservice.LogServerImpl.create_servant

# start
if [ -n "$debug" ] ;
then
    echo "INFO: Starting CORBA LogServer $name ..."
fi

@ECM.install.bin.dir@/corba_runtime_start.sh --location $location --entrypoint $entrypt $ns $debug $name

if [ -n "$debug" ] ;
then
    echo "INFO: The CORBA LogServer $name is started."
fi

