// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

/**
 **  <p>Generator class for home and component implementations.</p>
 **/
public class CIDLJImpl
extends org.objectweb.corba.command.lib.CommandOnASTBase
{
    //
    private org.objectweb.util.cmdline.lib.DefaultOptionArgument _outdir;

    // default constructor
    public
    CIDLJImpl()
    {
        super(new org.objectweb.util.cmdline.lib.DefaultCommandLine(
                   "cidl_jimpl",
                   "declaration",
                   "Generate the implementation for a home/component/module from the OpenCCM IR3",
                   true));

        // Option: -d <outputdir>
        _outdir = new org.objectweb.util.cmdline.lib.DefaultOptionArgument(
                        new String[] { "-d", "--outputdir" }, "outputdir",
                        new String[] { "Generate implementations into directory <outputdir>" },
                        null);

        // mandatory option
        _outdir.setMandatory(true);

        getCommandLine().addOption(_outdir);
    }

    //
    //  org.objectweb.corba.command.api.Application
    //

    final public int
    run(java.lang.String[] args)
    {
        // init the OpenCCM AST
        if(!initAST()) {
            return -1;
        }

        // obtain scope
        String declname = args[0];
        org.objectweb.corba.ast.api.Scope scope = null;
        try {
            scope = (org.objectweb.corba.ast.api.Scope)getAST().lookup(declname);
        } catch(ClassCastException e) {
            getConsole().error(declname+"must be a scope");
            return -1;
        }

        if(scope==null) {
            getConsole().error("Declaration "+declname +" not found");
            return -1;
        }

        //
        getConsole().message("Generating implementations for " + declname + "...");
        CIDLJImplGenerator gen = new CIDLJImplGenerator(getAST());

        try {
            gen.generate(_outdir.getArgument(), scope);
        } catch(org.objectweb.corba.generator.common.lib.GenerationException ex) {
            report_exception(ex);
            return -1;
        }

        getConsole().message("Implementations generated in "+_outdir.getArgument()+".");

        return 0;
    }

    //
    //  bootstrap
    //

    static public void
    main(String[] args)
    {
        CIDLJImpl cmd = new CIDLJImpl();
        cmd.runMain(args);
    }
}
