// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;
// import of OpenCCM modules
import org.objectweb.corba.ast.api.*;

/**
 **  <p>Generator class for client-side and server-side interceptors.</p>
 **/
public class ExtendedJavaTranslator
{
    // translator
    private org.objectweb.corba.generator.translator.idl2java.lib.CommonTranslator _translator;

    // default constructor
    public
    ExtendedJavaTranslator()
    {
        // translator
        _translator = new org.objectweb.corba.generator.translator.idl2java.lib.CommonTranslator();
    }

    //
    //  public operations
    //

    final public String
    toJava(TypeRef typeref)
    {
        return _translator.toJava(typeref);
    }

    final public String
    toJava(TypeRef type,
           int mode)
    {
        return _translator.toJava(type, mode);
    }

    final public String
    getAbsoluteName(Declaration decl)
    {
        return _translator.getAbsoluteName(decl);
    }

    final public String
    getPackage(Declaration decl)
    {
        return _translator.getPackage(decl);
    }

    final public String
    getAsDirectory(String packname)
    {
        return _translator.getAsDirectory(packname);
    }

    final public String
    getAsDirectory(Declaration decl)
    {
        return _translator.getAsDirectory(decl);
    }

    // returns null if no any extractor exists
    final public String
    toJavaAnyExtractor(TypeRef typeref)
    {
        TypeKind tk = typeref.getTypeKind();

        if (tk == TypeKind.tk_null)
            return null;
        else if (tk == TypeKind.tk_void)
            return null;
        else if (tk == TypeKind.tk_short)
            return "extract_short";
        else if (tk == TypeKind.tk_ushort)
            return "extract_ushort";
        else if (tk == TypeKind.tk_long)
            return "extract_long";
        else if (tk == TypeKind.tk_ulong)
            return "extract_long";
        else if (tk == TypeKind.tk_longlong)
            return "extract_longlong";
        else if (tk == TypeKind.tk_ulonglong)
            return "extract_ulonglong";
        else if (tk == TypeKind.tk_float)
            return "extract_float";
        else if (tk == TypeKind.tk_double)
            return "extract_double";
        else if (tk == TypeKind.tk_longdouble)
            return null;
        else if (tk == TypeKind.tk_boolean)
            return "extract_boolean";
        else if (tk == TypeKind.tk_char)
            return "extract_char";
        else if (tk == TypeKind.tk_wchar)
            return "extract_wchar";
        else if (tk == TypeKind.tk_octet)
            return "extract_octet";
        else if (tk == TypeKind.tk_any)
            return "extract_any";
        else if (tk == TypeKind.tk_Principal)
            return "extract_Principal";
        else if (tk == TypeKind.tk_TypeCode)
            return "extract_TypeCode";
        else if (tk == TypeKind.tk_objref)
            return "extract_Object";
        else if (tk == TypeKind.tk_string)
            return "extract_string";
        else if (tk == TypeKind.tk_wstring)
            return "extract_wstring";
        else if (tk == TypeKind.tk_fixed)
            return "extract_fixed";

        else 
            return getAbsoluteName((Declaration)typeref)+"Helper.extract";
    }

    // returns null if no any extractor exists
    final public String
    toJavaAnyInsertor(TypeRef typeref)
    {
        TypeKind tk = typeref.getTypeKind();

        if (tk == TypeKind.tk_null)
            return null;
        else if (tk == TypeKind.tk_void)
            return null;
        else if (tk == TypeKind.tk_short)
            return "insert_short";
        else if (tk == TypeKind.tk_ushort)
            return "insert_ushort";
        else if (tk == TypeKind.tk_long)
            return "insert_long";
        else if (tk == TypeKind.tk_ulong)
            return "insert_long";
        else if (tk == TypeKind.tk_longlong)
            return "insert_longlong";
        else if (tk == TypeKind.tk_ulonglong)
            return "insert_ulonglong";
        else if (tk == TypeKind.tk_float)
            return "insert_float";
        else if (tk == TypeKind.tk_double)
            return "insert_double";
        else if (tk == TypeKind.tk_longdouble)
            return null;
        else if (tk == TypeKind.tk_boolean)
            return "insert_boolean";
        else if (tk == TypeKind.tk_char)
            return "insert_char";
        else if (tk == TypeKind.tk_wchar)
            return "insert_wchar";
        else if (tk == TypeKind.tk_octet)
            return "insert_octet";
        else if (tk == TypeKind.tk_any)
            return "insert_any";
        else if (tk == TypeKind.tk_Principal)
            return "insert_Principal";
        else if (tk == TypeKind.tk_TypeCode)
            return "insert_TypeCode";
        else if (tk == TypeKind.tk_objref)
            return "insert_Object";
        else if (tk == TypeKind.tk_string)
            return "insert_string";
        else if (tk == TypeKind.tk_wstring)
            return "insert_wstring";
        else if (tk == TypeKind.tk_fixed)
            return "insert_fixed";

        else 
            return getAbsoluteName((Declaration)typeref)+"Helper.insert";
    }

    // return a "null" value 
    public String
    toJavaNullValue(TypeRef typeref)
    {
        TypeKind tk = typeref.getTypeKind();

        if (tk == TypeKind.tk_null)
            return null;
        else if (tk == TypeKind.tk_void)
            return null;
        else if (tk == TypeKind.tk_short)
            return "(short)0";
        else if (tk == TypeKind.tk_ushort)
            return "(short)0";
        else if (tk == TypeKind.tk_long)
            return "0";
        else if (tk == TypeKind.tk_ulong)
            return "0";
        else if (tk == TypeKind.tk_longlong)
            return "(long)0";
        else if (tk == TypeKind.tk_ulonglong)
            return "(long)0";
        else if (tk == TypeKind.tk_float)
            return "0.0";
        else if (tk == TypeKind.tk_double)
            return "0.0";
        else if (tk == TypeKind.tk_longdouble)
            return null;
        else if (tk == TypeKind.tk_boolean)
            return "false";
        else if (tk == TypeKind.tk_char)
            return "\'\'";
        else if (tk == TypeKind.tk_wchar)
            return "\'\'";
        else if (tk == TypeKind.tk_octet)
            return "0";
        else if (tk == TypeKind.tk_any)
            return "null";
        else if (tk == TypeKind.tk_Principal)
            return "null";
        else if (tk == TypeKind.tk_TypeCode)
            return "null";
        else if (tk == TypeKind.tk_objref)
            return "null";
        else if (tk == TypeKind.tk_string)
            return "null";
        else if (tk == TypeKind.tk_wstring)
            return "null";
        else if (tk == TypeKind.tk_fixed)
            return "0.0";

        else 
            return "null";
    }
}
