// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ecm.taskdefs;

/**
 **  <p>Set of static operations to ease file manipulation for the ant tasks.</p>
 **/
public class FileHelper
{
    static public java.io.File[]
    listFiles(java.io.File dir)
    {
        java.util.ArrayList files = new java.util.ArrayList();
        java.io.File[] childs = dir.listFiles();
        for (int i=0;i<childs.length;i++) {
            if (childs[i].isDirectory()) {
                files.addAll(java.util.Arrays.asList(listFiles(childs[i])));
            }
            else {
                files.add(childs[i]);
            }
        }

        return (java.io.File[])files.toArray(new java.io.File[0]);
    }

    static public void
    deleteDir(java.io.File dir)
    {
        //
        if (dir==null) {
            return ;
        }

        java.io.File[] files = dir.listFiles();
        if (files==null) {
            files = new java.io.File[0];
        }

        for (int i=0;i<files.length;i++) {
            if (files[i].isDirectory()) {
                deleteDir(files[i]);
            }
            else {
                files[i].delete();
            }
        }

        dir.delete();
    }

    static public void
    moveFiles(java.io.File[] files, java.io.File destdir)
    throws org.apache.tools.ant.BuildException
    {
        //
        if (destdir==null) {
            return ;
        }

        java.io.File destfile = null;
        // create dest dir if non-existent
        destdir.mkdirs();

        for (int i=0;i<files.length;i++) {
            // recurse on directories
            if (files[i].isDirectory()) {
                java.io.File ndestdir = new java.io.File(destdir, files[i].getName());
                moveFiles(files[i].listFiles(), ndestdir);
                continue;
            }

            destfile = new java.io.File(destdir, files[i].getName());
            // only move if dest file is older
            // NOTE: should not happen in our case
            if ((destfile.exists()) && (destfile.lastModified()>files[i].lastModified())) {
                continue;
            }

            // copy
            java.io.FileInputStream in = null;
            java.io.FileOutputStream out = null;
            try {
                // create dest file if non-existent first
                if (!destfile.exists()) {
                    destfile.createNewFile();
                }

                in = new java.io.FileInputStream(files[i]);
                out = new java.io.FileOutputStream(destfile);

                byte[] buffer = new byte[8*1024];
                int count = 0;
                do {
                    out.write(buffer, 0, count);
                    count = in.read(buffer, 0, buffer.length);
                } while (count!=-1);

            } catch (Exception ex) {
                String msg = "exception caught: "+ex.getMessage();
                ex.printStackTrace();
                throw new org.apache.tools.ant.BuildException(msg);
            } finally {
                if (in!=null) { try {in.close();} catch(java.io.IOException ex) {} }
                if (out!=null) { try {out.close();} catch(java.io.IOException ex) {} }
            }
        }
    }

    static public java.io.File
    createTempDir()
    throws org.apache.tools.ant.BuildException
    {
        // create temp file to obtain a path
        java.io.File tmpfile = null;
        try {
            tmpfile = java.io.File.createTempFile("temp", null);
        } catch (Exception ex) {
            throw new org.apache.tools.ant.BuildException(ex.getMessage());
        }

        String path = tmpfile.getPath();
        tmpfile.delete();

        // create temp directory
        java.io.File tmpdir = null;
        try {
            tmpdir = new java.io.File(path);
            tmpdir.mkdirs();
        } catch (Exception ex) {
            throw new org.apache.tools.ant.BuildException(ex.getMessage());
        }

        return tmpdir;
    }
}
