// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ecm.taskdefs;

/**
 **  <p>Concrete implementation of the <tt>IDLtoJavaTask</tt> for JacORB.</p>
 **/
public class JacORBIDLtoJavaTask
extends IDLtoJavaTask
{
    //

    // default constructor
    public
    JacORBIDLtoJavaTask()
    {
        //
    }

    //
    //  abstract operations implementation
    //

    final protected void
    compileIDL(java.io.File idlfile, java.io.File compileto,
               java.io.File[] includedirs, String prefix)
    {
        // use java task
        org.apache.tools.ant.Task task = getProject().createTask("java");
        org.apache.tools.ant.taskdefs.Java java = (org.apache.tools.ant.taskdefs.Java)task;
        java.setClassname("org.jacorb.idl.parser");
        java.setFork(true);
        java.setFailonerror(true);

        // create classpath
        org.apache.tools.ant.types.Path cp = java.createClasspath();
        // put path to JacORBOpenORB jar in cp
        // NOTE: use version independent path of JacORB for that
        cp.setRefid(new org.apache.tools.ant.types.Reference("JacORB.class.path"));
        org.apache.tools.ant.types.Commandline.Argument args = java.createArg();

        // build arg line
        // NOTE: include JacORB IDL directory by default
        OSHelper.pathConvert(getProject(), "os.JacORB.idl.dir", "JacORB.idl.dir");
        OSHelper.pathConvert(getProject(), "os.JacORB.idl.omg.dir", "JacORB.idl.omg.dir");
        String argline = "-D__JACORB__"+
            " -I"+getProject().getProperty("os.JacORB.idl.dir")+
            " -I"+getProject().getProperty("os.JacORB.idl.omg.dir");

        // add included directories
        for (int i=0;i<includedirs.length;i++) {
            argline = argline+" -I"+includedirs[i].getPath();
        }

        // add "-jdk14 i2jline -d compileto idlfile"
        //   -jdk14   do compatibility checks for JDK 1.4
        //   -d       set output directory

        //
        String i2jline = " -i2jpackage CORBA:org.omg.CORBA "+
            " -i2jpackage CosNaming:org.omg.CosNaming "+
            " -i2jpackage CosTransactions:org.omg.CosTransactions "+
            " -i2jpackage CosPersistentState:org.omg.CosPersistentState "+
            " -i2jpackage CosTrading:org.omg.CosTrading "+
            " -i2jpackage CosTradingRepos:org.omg.CosTradingRepos "+
            " -i2jpackage CosTradingDynamic:org.omg.CosTradingDynamic "+
            " -i2jpackage Components:org.omg.Components "+
            // TODO: use external config for that !
            " -i2jpackage objectweb:org.objectweb "+
            " -i2jpackage ECA:org.coach.ECA "+
            " -i2jpackage ECM:org.coach.ECM ";

        argline = argline+i2jline+" -W 1 -d "+compileto.getPath()+" "+idlfile.getPath();
        //log("[compileIDL] argline: "+argline);
        args.setLine(argline);

        // execute
        java.execute();
    }
}
