// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ecm.taskdefs;

/**
 **  <p>Concrete implementation of the <tt>IDLtoJavaTask</tt> for ORBacus.</p>
 **/
public class ORBacusIDLtoJavaTask
extends IDLtoJavaTask
{
    //

    // default constructor
    public
    ORBacusIDLtoJavaTask()
    {
        //
    }

    //
    //  abstract operations implementation
    //

    final protected void
    compileIDL(java.io.File idlfile, java.io.File compileto,
               java.io.File[] includedirs, String prefix)
    {
        // use the exec task
        org.apache.tools.ant.taskdefs.ExecTask cmd = null;
        cmd = (org.apache.tools.ant.taskdefs.ExecTask)getProject().createTask("exec");

        // convert "ORBacus.bin.dir" to OS specific path
        OSHelper.pathConvert(getProject(), "os.ORBacus.bin.dir", "ORBacus.bin.dir");

        String cmdname = "jidl";
        if (OSHelper.isUnix()) {
            cmdname = getProject().getProperty("os.ORBacus.bin.dir")+"/jidl";
        }
        else if (OSHelper.isWindows()) {
            cmdname = getProject().getProperty("os.ORBacus.bin.dir")+"\\jidl";
        }

        cmd.setExecutable(cmdname);

        // add LD_LIBRARY_PATH to ${ORBacus.lib.dir}${PSEP}${LD_LIBRARY_PATH}
        OSHelper.pathConvert(getProject(), "os.ORBacus.lib.dir", "ORBacus.lib.dir");
        String slibpath = getProject().getProperty("os.ORBacus.lib.dir")+
            java.io.File.pathSeparator+
            OSHelper.envVar("LD_LIBRARY_PATH");

        //log("[compileIDL] LD_LIBRARY_PATH="+slibpath);
        org.apache.tools.ant.types.Environment.Variable libpath_env = new org.apache.tools.ant.types.Environment.Variable();
        libpath_env.setKey("LD_LIBRARY_PATH");
        org.apache.tools.ant.types.Path libpath = new org.apache.tools.ant.types.Path(getProject());
        libpath.setPath(slibpath);
        libpath_env.setPath(libpath);
        cmd.addEnv(libpath_env);

        // build arg line
        // NOTE: include ORBacus IDL directory by default
        OSHelper.pathConvert(getProject(), "os.ORBacus.idl.dir", "ORBacus.idl.dir");
        String argline = "-D__ORBACUS__"+
            " -I"+getProject().getProperty("os.ORBacus.idl.dir");
        // add included directories
        for (int i=0;i<includedirs.length;i++) {
            argline = argline+" -I"+includedirs[i].getPath();
        }

        //
        String ppline = " --prefix-package omg.org org.omg "+
            " --prefix-package coach.org org.coach "+
            " --prefix-package objectweb.org org.objectweb ";

        // add "--auto-package --tie --output-dir compileto idlfile"
        org.apache.tools.ant.types.Commandline.Argument arg = cmd.createArg();
        argline = argline+ppline+" --tie --output-dir "+compileto.getPath()+" "+idlfile.getPath();
        //log("[compileIDL] argline: "+argline);
        arg.setLine(argline);

        // launch
        cmd.execute();
    }
}
