// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ecm.taskdefs;

/**
 **  <p>Set of static operations to ease OS specific manipulations for the Ant tasks.</p>
 **/
public class OSHelper
{
    //
    static private String _ospath;
    static private boolean _isunix;
    static private boolean _iswindows;
    static private String _osfamily;

    //
    static {
        _ospath = null;
        _isunix = org.apache.tools.ant.taskdefs.condition.Os.isFamily("unix");
        _iswindows = org.apache.tools.ant.taskdefs.condition.Os.isFamily("windows");

        if (_isunix) {
            _osfamily = "unix";
        }
        else if (_iswindows) {
            _osfamily = "windows";
        }
    }

    //
    //  
    //

    static public boolean
    isUnix()
    {
        return _isunix;
    }

    static public boolean
    isWindows()
    {
        return _iswindows;
    }

    static public String
    osFamily()
    {
        return _osfamily;
    }

    static public String
    osPath()
    {
        if (_ospath==null) {
            java.util.Vector procenv = org.apache.tools.ant.taskdefs.Execute.getProcEnvironment();
            String vname = null;
            if (isUnix()) {
                vname = "PATH";
            }
            else if (isWindows()) {
                vname = "Path";
            }

            String[] vars = (String[])procenv.toArray(new String[0]);
            for (int i=0;i<vars.length;i++) {
                if (vars[i].startsWith(vname)) {
                    int idx = vars[i].indexOf('=');
                    _ospath = vars[i].substring(idx+1);
                    break;
                }
            }

        }

        // if still null, then error (how to report this?)

        return _ospath;
    }

    static public String
    envVar(String vname)
    {
        java.util.Vector procenv = org.apache.tools.ant.taskdefs.Execute.getProcEnvironment();
        String[] vars = (String[])procenv.toArray(new String[0]);
        for (int i=0;i<vars.length;i++) {
            if (vars[i].startsWith(vname)) {
                int idx = vars[i].indexOf('=');
                return vars[i].substring(idx+1);
            }
        }

        return null;
    }

    static public void
    pathConvert(org.apache.tools.ant.Project project,
                String prop, String spath)
    {
        org.apache.tools.ant.taskdefs.PathConvert pconvert = null;
        org.apache.tools.ant.types.Path path = null;
        pconvert = (org.apache.tools.ant.taskdefs.PathConvert)project.createTask("pathconvert");
        pconvert.setTargetos(osFamily());
        pconvert.setProperty(prop);
        path = pconvert.createPath();

        // try to use spath as a property name
        String rpath = project.getProperty(spath);
        if (rpath!=null) {
            path.setPath(rpath);
        }
        // use spath as a path
        else {
            path.setPath(spath);
        }

        pconvert.execute();
    }
}
