// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p>Default implementation of the <tt>Components::ComponentServer</tt> interface.</p>
 **/
public class ComponentServerImpl
extends org.omg.CORBA.LocalObject
implements Servant, org.omg.Components.Deployment.ComponentServerOperations
{
    // component server
    static private String _class_name = "ComponentServerImpl";
    static final private String _type_id =  org.omg.Components.Deployment.ComponentServerHelper.id();
    private ORBService _orb_service;
    private POAService _cont_poa_service;
    private java.util.ArrayList _cont_refs;  // (list of ::Components::Deployment::Container)
    private org.omg.Components.ConfigValue[] _configuration;
    private org.omg.Components.Deployment.ServerActivator _sa_ref;

    // default constructor
    public
    ComponentServerImpl()
    {
        // component server
        _orb_service = null;
        _cont_poa_service = null;
        _cont_refs = new java.util.ArrayList();
        _configuration = new org.omg.Components.ConfigValue[0];
        _sa_ref = null;
    }

    //
    //  Entry point
    //

    static public Servant
    create_servant()
    {
        return new ComponentServerImpl();
    }

    //
    //  internal operations
    //

    //
    //  IDL:org/objectweb/corba/runtime/SystemComponent:1.0
    //

    final public void
    system_configuration_complete(SystemConfiguration cfg)
    {
        // obtain services
        ServantConfiguration scfg = (ServantConfiguration)cfg;
        _orb_service = scfg.orb_service();

        // create POA service for container servants
        FactoryFinderService ffs = org.objectweb.corba.runtime.Runtime.getFFService();
        SystemFactory poafact = ffs.find_service_factory(POAService.SERVICE_ID);

        // configuration (requires ORB service)
        // params: no name, no pols, _orb_service
        POAConfiguration poacfg = new POAConfigurationImpl(null, null, _orb_service);
        _cont_poa_service = (POAService)poafact.create_system_component(poacfg);

        // register ConfigValue factory
        String typeid = org.omg.Components.ConfigValueHelper.id();
        org.omg.CORBA.portable.ValueFactory fact = org.objectweb.ccm.runtime.ConfigValueFactoryImpl.create_factory();
        _orb_service.register_valuefactory(new ValueFactoryImpl(typeid, fact));

        // NOTE: how is the ServerActivator reference obtained ?
        //  - using the (local) name service
        //  - using a config value
        //  - other ?
    }

    final public void
    destroy()
    {
        // destroy all created container
        org.omg.Components.Deployment.Container[] refs = get_containers();
        for (int i=0;i<refs.length;i++) {
            try {
                // 
                refs[i].remove();

                // NOTE: deactivate container servant
                byte[] cid = _cont_poa_service.get_id_from_ref(refs[i]);
                _cont_poa_service.deactivate_servant(cid);
            } catch (org.omg.Components.RemoveFailure ex) {
                // ignore
                final String opname = "destroy";
                TheLogger.debug(_class_name, opname, "IGNORE", ex);
                return ;
            }
        }

        // clear list
        _cont_refs.clear();

        // destroy container POA service
        _cont_poa_service.destroy();
    }

    //
    //  IDL:org/objectweb/corba/runtime/Servant:1.0
    //

    final public String
    type_id()
    {
        return _type_id;
    }

    final public org.omg.PortableServer.Servant
    as_native_servant()
    {
        return new org.omg.Components.Deployment.ComponentServerPOATie(this);
    }

    //
    //  IDL:omg.org/Components/Deployment/ComponentServer:1.0
    //

    final public org.omg.Components.ConfigValue[]
    configuration()
    {
        return _configuration;
    }

    final public org.omg.Components.Deployment.ServerActivator
    get_server_activator()
    {
        return _sa_ref;
    }

    final public org.omg.Components.Deployment.Container
    create_container(org.omg.Components.ConfigValue[] config)
    throws org.omg.Components.CreateFailure,
           org.omg.Components.Deployment.InvalidConfiguration
    {
        // NOTE: currently, the container created in this way does not support
        // ECM services, so the configuration is not used
        // NOTE: TODO ASAP

        // create instance
        ContainerImpl cont = new ContainerImpl();

        // create configuration
        ServantConfiguration scfg = new ServantConfigurationImpl(_orb_service, _cont_poa_service);
        cont.system_configuration_complete(scfg);

        // create ref and activate servant
        // fake oid
        byte[] oid = Double.toString(Math.random()).getBytes();
        org.omg.CORBA.Object ref = _cont_poa_service.create_ref_with_id(oid, cont.type_id());
        _cont_poa_service.activate_servant_with_id(cont, oid);

        // store
        org.omg.Components.Deployment.Container cref = org.omg.Components.Deployment.ContainerHelper.narrow(ref);
        _cont_refs.add(cref);

        return cref;
    }

    final public void
    remove_container(org.omg.Components.Deployment.Container cref)
    throws org.omg.Components.RemoveFailure
    {
        // remove from storage
        org.omg.Components.Deployment.Container[] refs = get_containers();
        int i=0;
        for (;i<refs.length;i++) {
            if (cref._is_equivalent(refs[i])) {
                _cont_refs.remove(i);

                // NOTE: only call remove on the container if it was found
                cref.remove();

                // NOTE: deactivate container servant
                byte[] cid = _cont_poa_service.get_id_from_ref(cref);
                _cont_poa_service.deactivate_servant(cid);

                break;
            }
        }

        // if it wasn't found, report removal failure
        if (i==refs.length) {
            throw new org.omg.Components.RemoveFailure();
        }
    }

    final public org.omg.Components.Deployment.Container[]
    get_containers()
    {
        return (org.omg.Components.Deployment.Container[])_cont_refs.toArray(new org.omg.Components.Deployment.Container[0]);
    }

    final public void
    remove()
    throws org.omg.Components.RemoveFailure
    {
        // destroy
        destroy();
    }
}

