// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p></p>
 **
 **  <p><i>NOTE: the <tt>archives.autoload</tt> system property may be set with a list of comma
 **  separated pattern "uuid=location". Each pattern shall correspond to an archive which
 **  will be installed using the UUID "uuid" and from the location "location".</i></p>
 **/
public class ExtComponentInstallationImpl
extends org.omg.CORBA.LocalObject
implements Servant, org.coach.ECM.ExtComponentInstallationOperations
{
    // system component
    static final private String _class_name = "ExtComponentInstallationImpl";

    // servant
    static final private String _type_id =  org.coach.ECM.ExtComponentInstallationHelper.id();

    // component installation
    private java.util.Hashtable _uuid2location; // (::Components::Deployment::UUID, URL)
    private String _zip_cache;
    private int _archive_number;
    private String _dtd_location;

    // extended component installation
    private java.util.Hashtable _uuid2sarch;    // (::Components::Deployment::UUID, ServiceArchiveServantImpl)
    private java.util.Hashtable _uuid2carch;    // (::Components::Deployment::UUID, ComponentArchiveServantImpl)
    private POAService _poa_service;
    private ORBService _orb_service;

    // default constructor
    protected
    ExtComponentInstallationImpl()
    {
        // component installation
        _uuid2location = new java.util.Hashtable();
        _zip_cache = ".";
        _archive_number = 0;
        _dtd_location = ".";

        // extended component installation
        _uuid2sarch = new java.util.Hashtable();
        _uuid2carch = new java.util.Hashtable();
        _poa_service = null;
        _orb_service = null;
    }

    //
    //  Entry point
    //

    static public Servant
    create_servant()
    {
        return new ExtComponentInstallationImpl();
    }

    //
    //  IDL:org/objectweb/corba/runtime/SystemComponent:1.0
    //

    final public void
    system_configuration_complete(SystemConfiguration cfg)
    {
        final String opname = "system_configuration_complete";
        // obtain zip cache directory
        String zc = System.getProperty("zip.cache");
        if (zc!=null) {
            _zip_cache = zc;
        }

        // obtain DTDs location
        String loc = System.getProperty("dtd.location");
        if (loc!=null) {
            _dtd_location = loc;
        }

        // obtain services
        ServantConfiguration scfg = (ServantConfiguration)cfg;
        _poa_service = scfg.poa_service();
        _orb_service = scfg.orb_service();

        // check if some auto-loaded archives are set
        String auto = System.getProperty("archives.autoload");
        if (auto==null) {
            return ;
        }

        // break the string
        java.util.Vector varchives = new java.util.Vector();
        int idx = auto.indexOf(',');
        String pattern = "";
        while (idx!=-1) {
            pattern = auto.substring(0, idx);
            if (!pattern.equals("")) {
                varchives.add(pattern);
            }

            auto = auto.substring(idx+1);
            idx = auto.indexOf(',');
        }

        varchives.add(auto);

        // install the archives
        String[] archives = (String[])varchives.toArray(new String[0]);
        for (int i=0;i<archives.length;i++) {
            // look for the pattern "<uuid>=<location>"
            // look for the "="
            idx = archives[i].indexOf("=");

            try {
                String msg = "autoload: "+archives[i].substring(0, idx);
                TheLogger.debug(_class_name, opname, msg);
                msg = "location: "+archives[i].substring(idx+1);
                TheLogger.debug(_class_name, opname, msg);

                install(archives[i].substring(0, idx), archives[i].substring(idx+1));
            } catch(Exception ex) {
                final String msg = "FAILED (UUID: "+archives[i].substring(0, idx)+")";
                TheLogger.error(_class_name, opname, msg, ex);
            }
        }
    }

    final public void
    destroy()
    {
        // TODO
    }

    //
    //  IDL:org/objectweb/corba/runtime/Servant:1.0
    //

    final public String
    type_id()
    {
        return _type_id;
    }

    final public org.omg.PortableServer.Servant
    as_native_servant()
    {
        return new org.coach.ECM.ExtComponentInstallationPOATie(this);
    }

    //
    //  IDL:coach.org/runtime/deployment/ExtComponentInstallation:1.0
    //

    final public org.coach.ECM.ServiceArchive
    get_service_archive(String uuid)
    {
        final String opname = "get_service_archive";
        // NOTE: to avoid complex implementation of the ServiceArchive interface,
        // the same object instance is returned for a given uuid
        // That way, we don't have to take care about local file management problem
        // (in particular, if many instances share the same archive, then files may be
        // extracted twice or more, ...)

        // NOTE2: currently, the service archive is a servant, but it is not really necessary
        // Maybe, it could be a simple object

        // check if an instance is already ready for this uuid
        ServiceArchiveImpl sarch = (ServiceArchiveImpl)_uuid2sarch.get(uuid);

        if (sarch==null) {
            String archloc = (String)_uuid2location.get(uuid);

            // check if uuid is known
            if (archloc==null) {
                // NOTE: TODO: should throw an exception instead
                final String msg = "FAILED (unknown uuid: "+uuid+")";
                TheLogger.error(_class_name, opname, msg);
            }

            sarch = new ServiceArchiveImpl(_orb_service, _dtd_location, uuid, archloc);
            sarch.system_configuration_complete(null);

            // store
            _uuid2sarch.put(uuid, sarch);

            // activate
            // use UUID as oid
            _poa_service.activate_servant_with_id(sarch, uuid.getBytes());
        }

        //
        org.omg.CORBA.Object obj = _poa_service.create_ref_with_id(uuid.getBytes(), sarch.type_id());
        return org.coach.ECM.ServiceArchiveHelper.narrow(obj);
    }

    final public org.coach.ECM.ComponentArchive
    get_component_archive(String uuid)
    {
        final String opname = "get_component_archive";
        // NOTE: to avoid complex implementation of the ComponentArchive interface,
        // the same object instance is returned for a given uuid
        // That way, we don't have to take care about local file management problem
        // (in particular, if many instances share the same archive, then files may be
        // extracted twice or more, ...)

        // NOTE2: currently, the component archie is a servant, but it is not really necessary
        // Maybe, it could be a simple object

        // check if an instance is already ready for this uuid
        ComponentArchiveImpl carch = (ComponentArchiveImpl)_uuid2carch.get(uuid);

        if (carch==null) {
            String archloc = (String)_uuid2location.get(uuid);

            // check if uuid is known
            if (archloc==null) {
                // NOTE: TODO: should throw an exception instead
                final String msg = "FAILED (unknown uuid: "+uuid+")";
                TheLogger.error(_class_name, opname, msg);
            }

            carch = new ComponentArchiveImpl(this, _orb_service, _dtd_location, uuid, archloc);
            carch.system_configuration_complete(null);

            // store
            _uuid2carch.put(uuid, carch);

            // activate
            // use UUID as oid
            _poa_service.activate_servant_with_id(carch, uuid.getBytes());
        }

        //
        org.omg.CORBA.Object obj = _poa_service.create_ref_with_id(uuid.getBytes(), carch.type_id());
        return org.coach.ECM.ComponentArchiveHelper.narrow(obj);
    }

    //
    //  IDL:omg.org/Components/Deployment/ComponentInstallation:1.0
    //

    final public void
    install(String uuid, String location)
    throws org.omg.Components.Deployment.InvalidLocation,
           org.omg.Components.Deployment.InstallationFailure
    {
        final String opname = "install";
        // try to open as local file
        java.io.InputStream in = null;
        try {
            in = new java.io.FileInputStream(location);
        } catch (java.io.FileNotFoundException ex) {
            // ignore
        }

        if (in==null) {
            // try to open as URL
            java.net.URL url = null;
            try {
                url = new java.net.URL(location);
                in = url.openStream();
            } catch (Exception ex) {
                // ignore
            }
        }

        if (in==null) {
            final String msg = "FAILED (invalid format, rethrown)";
            TheLogger.debug(_class_name, opname, msg);
            throw new org.omg.Components.Deployment.InvalidLocation();
        }

        // create local file
        java.io.FileOutputStream out = null;
        String fname = _zip_cache
            + "/archive_"
            + java.lang.Integer.toString(_archive_number)
            + ".zip";

        try {
            out = new java.io.FileOutputStream(fname);
        } catch (java.io.FileNotFoundException ex) {
            final String msg = "FAILED (file not found, rethrown)";
            TheLogger.debug(_class_name, opname, msg, ex);
            throw new org.omg.Components.Deployment.InvalidLocation();
        }

        int nread = 0;
        byte[] buffer = new byte[2048];
        try {
            while (nread!=-1) {
                nread = in.read(buffer, 0, 2048);
                if (nread!=-1) out.write(buffer, 0, nread);
            }

            in.close();
            out.close();
        } catch (java.io.IOException ex) {
            final String msg = "FAILED (download aborted, rethrown)";
            TheLogger.debug(_class_name, opname, msg, ex);
            throw new org.omg.Components.Deployment.InstallationFailure();
        }

        // store location with uuid and increase the archive number
        _uuid2location.put(uuid, fname);
        _archive_number++;
    }

    final public void
    replace(String uuid, String location)
    throws org.omg.Components.Deployment.InvalidLocation,
           org.omg.Components.Deployment.InstallationFailure
    {
        final String opname = "replace";
        final String msg = "FAILED (not implemented, rethrown)";
        TheLogger.debug(_class_name, opname, msg);

        // TODO: implement
        throw new org.omg.CORBA.NO_IMPLEMENT();
    }

    final public void
    remove(String uuid)
    throws org.omg.Components.Deployment.UnknownImplId,
           org.omg.Components.RemoveFailure
    {
        final String opname = "remove";
        final String msg = "FAILED (not implemented, rethrown)";
        TheLogger.debug(_class_name, opname, msg);

        // TODO: implement
        throw new org.omg.CORBA.NO_IMPLEMENT();
    }

    final public String
    get_implementation(String uuid)
    throws org.omg.Components.Deployment.UnknownImplId,
           org.omg.Components.Deployment.InstallationFailure
    {
        final String opname = "get_implementation";
        final String msg = "FAILED (not implemented, rethrown)";
        TheLogger.debug(_class_name, opname, msg);

        // TODO: implement
        throw new org.omg.CORBA.NO_IMPLEMENT();
    }
}
