// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 ** <p>Default implementation of the <tt>Service</tt> OMG IDL interface.</p>
 **/
public class ServiceImpl
extends org.omg.CORBA.LocalObject
implements Service
{
    // service
    private String _service_id;
    private String _impl_uuid;
    private CORBAServiceRef _corba_service_ref;
    private java.util.Hashtable _internals;
    private java.util.Hashtable _policy_factories;
    private String _orb_init;
    private org.coach.ECA.CallControllerFactory _controller_factory;
    private org.coach.ECA.ServiceInitializer _service_initializer;
    private CallControllerInitInfoImpl _controller_iinfo;

    // default constructor
    public
    ServiceImpl(String sid, String uuid)
    {
        _service_id = sid;
        _impl_uuid = uuid;
        _corba_service_ref = null;
        _internals = new java.util.Hashtable();
        _policy_factories = new java.util.Hashtable();
        _orb_init = null;
        _controller_factory = null;

        _controller_iinfo = null;
    }

    //
    //  internal state getter/setter
    //

    private CallControllerInitInfoImpl
    getControllerIInfo()
    {
        if (_controller_iinfo==null) {
            // create call controller init info
            _controller_iinfo = new CallControllerInitInfoImpl();
            // set slot factory
            // not mandatory (=> use singleton factory)
        }

        return _controller_iinfo;
    }

    //
    //  IDL:org/objectweb/ccm/runtime/Service:1.0
    //

    final public String
    service_id()
    {
        return _service_id;
    }

    final public String 
    implementation_uuid()
    {
        return _impl_uuid;
    }

    final public org.omg.CORBA.Object
    get_service_internal(String sid)
    {
        return (org.omg.CORBA.Object)_internals.get(sid);
    }

    final public Policy
    create_policy(String ptype, String pvalue)
    {
        // create corba policy
        org.coach.ECA.PolicyFactory pfact = (org.coach.ECA.PolicyFactory)_policy_factories.get(ptype);
        org.omg.CORBA.Policy pol = pfact.create_policy(ptype, pvalue);

        // create new Policy
        PolicyImpl policy = new PolicyImpl(this, pol);

        // store ?

        //
        return policy;
    }

    //
    //  public operations
    //

    final public CORBAServiceRef
    getCorbaServiceRef()
    {
        return _corba_service_ref;
    }

    final public void
    setCorbaServiceRef(CORBAServiceRef csref)
    {
        _corba_service_ref = csref;
    }

    final public org.coach.ECA.ServiceInitializer
    getServiceInitializer()
    {
        return _service_initializer;
    }

    final public void
    setServiceInitializer(org.coach.ECA.ServiceInitializer sinit)
    {
        _service_initializer = sinit;
    }

    final public void
    addServiceInternal(String sid, org.omg.CORBA.Object internal)
    {
        _internals.put(sid, internal);
    }

    final public void
    addPolicyFactory(String ptype, org.coach.ECA.PolicyFactory fact)
    {
        _policy_factories.put(ptype, fact);
    }

    final public String
    getORBInitializer()
    {
        return _orb_init;
    }

    final public void
    setORBInitializer(String orbinit)
    {
        _orb_init = orbinit;
    }

    final public void
    setCallControllerFactory(org.coach.ECA.CallControllerFactory fact)
    {
        _controller_factory = fact;
    }

    final public org.coach.ECA.CallController
    createCallController(Policy pol)
    {
        return _controller_factory.create_call_controller(pol.corba_policy(), getControllerIInfo());
    }
}
