// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.ccm.runtime;

import org.objectweb.corba.runtime.*;

/**
 **  <p>Default implementation of the <tt>ECA::ServiceInitInfo</tt> interface.</p>
 **/
public class ServiceInitInfoImpl
extends org.omg.CORBA.LocalObject
implements org.coach.ECA.ServiceInitInfo
{
    //
    private String _class_name = "ServiceInitInfoImpl";
    private ORBService _orb_service;
    private java.util.Hashtable _orb_inits;                 // (ECM::ServiceId, String)
    private java.util.Hashtable _value_factories;           // (repid, ::ccm::runtime::ValueFactory)
    private java.util.Hashtable _policy_factories;          // (ECA::PolicyType, ECA::PolicyFactory)
    private java.util.Hashtable _services;                  // (ECM::ServiceId, ::ccm::runtime::Service)
    private java.util.Hashtable _initial_references;        // (string, CORBA::Object)
    private java.util.Hashtable _stringified_initial_references; // (string, string)

    public
    ServiceInitInfoImpl(ServiceImpl[] services,
                        CORBAServiceRef[] degenservices)
    {
        _orb_service = null;
        _orb_inits = new java.util.Hashtable();
        _value_factories = new java.util.Hashtable();
        _policy_factories = new java.util.Hashtable();
        _services = new java.util.Hashtable();
        _initial_references = new java.util.Hashtable();
        _stringified_initial_references = new java.util.Hashtable();

        CORBAServiceRef csref = null;
        for (int i=0;i<services.length;i++) {
            csref = services[i].getCorbaServiceRef();
            if (csref!=null) {
                if (csref.initial_reference!=null) {
                    _initial_references.put(csref.orb_registration_name, csref.initial_reference);
                }
                else {
                    _stringified_initial_references.put(csref.orb_registration_name, csref.stringified_initial_reference);
                }
            }
            

            _services.put(services[i].service_id(), services[i]);
        }

        for (int i=0;i<degenservices.length;i++) {
            csref = degenservices[i];
            if (csref.initial_reference!=null) {
                _initial_references.put(csref.orb_registration_name, csref.initial_reference);
            }
            else {
                _stringified_initial_references.put(csref.orb_registration_name, csref.stringified_initial_reference);
            }
        }
    }

    //
    //  public operations
    //

    final public void
    setORBService(ORBService orbs)
    {
        _orb_service = orbs;
    }

    final public ORBConfiguration
    getORBConfiguration()
    {
        // orb initializer
        String[] inits = (String[])_orb_inits.values().toArray(new String[0]);

        // value factories
        ValueFactory[] vfacts = (ValueFactory[])_value_factories.values().toArray(new ValueFactory[0]);

        // initial references
        String[] names = (String[])_initial_references.keySet().toArray(new String[0]);
        org.omg.CORBA.Object[] refs = (org.omg.CORBA.Object[])_initial_references.values().toArray(new org.omg.CORBA.Object[0]);
        InitialReference[] irefs = new InitialReference[names.length];

        for (int i=0;i<names.length;i++) {
            irefs[i] = new InitialReference();
            irefs[i].name = names[i];
            irefs[i].ref = refs[i];
        }

        // stringified initial references
        names = (String[])_stringified_initial_references.keySet().toArray(new String[0]);
        String[] srefs = (String[])_stringified_initial_references.values().toArray(new String[0]);
        StringifiedInitialReference[] sirefs = new StringifiedInitialReference[names.length];

        for (int i=0;i<names.length;i++) {
            sirefs[i] = new StringifiedInitialReference();
            sirefs[i].name = names[i];
            sirefs[i].ref = srefs[i];
        }

        return new ORBConfigurationImpl(inits, vfacts, irefs, sirefs);
    }

    //
    //  IDL:coach.org/ECA/ServiceInitInfo:1.0
    //

    final public org.omg.CORBA.Object
    resolve_initial_references(String name)
    {
        // TODO: trap some initial refs

        // some initial references are available even if no ORB instance
        // is set, these are
        //   - degenerated service initial references
        //   - initial references specified in usedservice/corbaserviceref element
        org.omg.CORBA.Object ref = (org.omg.CORBA.Object)_initial_references.get(name);
        if (ref!=null) {
            return ref;
        }

        // check if ORB service set <=> post_install
        if (_orb_service==null) {
            // NOTE: TODO: should throw an exception instead (like in the PI)
            final String opname = "resolve_initial_references";
            final String msg = "IGNORE (operation can not be called in pre_install)";
            TheLogger.debug(_class_name, opname, msg);
            return null;
        }

        return _orb_service.resolve_initial_references(name);
    }

    final public org.omg.CORBA.Current
    get_current(String cname)
    {
        // TODO: trap some currents

        // check if ORB service set <=> post_install
        if (_orb_service==null) {
            final String opname = "get_current";
            final String msg = "IGNORE (operation can not be called in pre_install)";
            TheLogger.debug(_class_name, opname, msg);
            return null;
        }

        return org.omg.CORBA.CurrentHelper.narrow(_orb_service.resolve_initial_references(cname));
    }

    final public void
    register_orb_initializer(String sid, String orbinit)
    {
        // obtain Service for the service id
        ServiceImpl sinst = (ServiceImpl)_services.get(sid);

        // set orb init
        sinst.setORBInitializer(orbinit);

        // store
        _orb_inits.put(sid, orbinit);
    }

    final public void
    register_service_internal(String sid, String internal_id,
                              org.omg.CORBA.Object internal)
    {
        // obtain Service for the service id
        ServiceImpl sinst = (ServiceImpl)_services.get(sid);

        // add internal
        sinst.addServiceInternal(internal_id, internal);
    }

    final public void
    register_controller_factory(String sid,
                                org.coach.ECA.CallControllerFactory fact)
    {
        // obtain Service for the service id
        ServiceImpl sinst = (ServiceImpl)_services.get(sid);

        // set factory
        sinst.setCallControllerFactory(fact);
    }

    final public void
    register_value_factory(String sid, String typeid,
                           org.omg.CORBA.portable.ValueFactory fact)
    {
        // NOTE: are the value factories stored in the service ?
        // is this of any use ??? (for clean removal of the service ?)

        // create struct
        ValueFactory vfact = new ValueFactoryImpl(typeid, fact);

        // store
        _value_factories.put(sid, vfact);
    }

    final public void
    register_policy_factory(String sid, String ptype,
                            org.coach.ECA.PolicyFactory fact)
    {
        // obtain Service for the service id
        ServiceImpl sinst = (ServiceImpl)_services.get(sid);

        // add policy factory
        sinst.addPolicyFactory(ptype, fact);
    }
}
