// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.runtime;

/**
 **  <p>Default implementation of the <tt>ORBService</tt> system service.</p>
 **/
public class ORBServiceImpl
extends org.omg.CORBA.LocalObject
implements ORBService
{
    // orb service
    static final private String _class_name = "ORBServiceImpl";
    static final private String _service_id = ORBService.SERVICE_ID;
    private org.omg.CORBA.ORB _orb;
    private java.util.Hashtable _initial_references;

    // default constructor
    protected
    ORBServiceImpl(org.omg.CORBA.ORB orb)
    {
        // orb service
        _orb = orb;
        _initial_references = null;
    }

    //
    //  internal operations
    //


    //
    //  public operations
    //

    final public org.omg.CORBA.ORB
    getORB()
    {
        return _orb;
    }

    //
    //  IDL:objectweb.org/corba/runtime/SystemComponent:1.0
    //

    final public void
    system_configuration_complete(SystemConfiguration cfg)
    {
        _initial_references = new java.util.Hashtable();
    }

    final public void
    destroy()
    {
        // NOTE: as destroy calls shutdown for 'wait_for_completion' param as true, we have
        // to destroy the ORB before removing it from the main thread
        // otherwise, the ORB will never have any time slot to finish its shutdown

        // destroy ORB
        _orb.shutdown(true);

        // remove ORB from main thread
        Runtime.getMainThread().stopORB(_orb);

        // clean init ref table
        _initial_references.clear();
    }

    //
    //  IDL:objectweb.org/corba/runtime/SystemService:1.0
    //

    final public String
    service_id()
    {
        return _service_id;
    }

    //
    //  IDL:objectweb.org/corba/runtime/ORBService:1.0
    //

    final public org.omg.CORBA.Object
    string_to_object(String str)
    {
        // always use extracted IOR (to handle file: or http: IORs)
        return _orb.string_to_object(ORBFactoryImpl.extractIOR(str));
    }

    final public String
    object_to_string(org.omg.CORBA.Object obj)
    {
        return _orb.object_to_string(obj);
    }

    final public org.omg.CORBA.Any
    create_any()
    {
        return _orb.create_any();
    }

    final public org.omg.CORBA.Policy
    create_policy(int type, org.omg.CORBA.Any value)
    {
        try {
            return _orb.create_policy(type, value);
        } catch (org.omg.CORBA.PolicyError ex) {
            // ignore
            final String opname = "create_policy";
            TheLogger.debug(_class_name, opname, "IGNORE", ex);
            return null;
        }
    }

    final public java.io.Serializable
    create_valuetype(String repid)
    {
        final String opname = "create_valuetype";

        // find ValueFactory
        org.omg.CORBA_2_3.ORB orb23 = (org.omg.CORBA_2_3.ORB)_orb;
        org.omg.CORBA.portable.ValueFactory vfact = orb23.lookup_value_factory(repid);

        // check if found
        if (vfact==null) {
            final String msg = "IGNORE (no factory for: "+repid+")";
            TheLogger.debug(_class_name, opname, msg);
            return null;
        }

        // try to create new instance
        // assume "create_valuetype" as operation name
        String opn = "create_valuetype";
        try {
            java.lang.reflect.Method op = null;
            op = vfact.getClass().getMethod(opn, new Class[0]);
            return (java.io.Serializable)op.invoke(null, new Object[0]);
        } catch (NoSuchMethodException ex) {
            final String msg = "IGNORE (no \"create_valuetype\" operation for: "+repid+")";
            TheLogger.debug(_class_name, opname, msg, ex);
            return null;
        } catch (Exception ex) {
            TheLogger.debug(_class_name, opname, "IGNORE", ex);
            return null;
        }
    }

    final public void
    register_valuefactory(ValueFactory vfact)
    {
        org.omg.CORBA_2_3.ORB orb23 = (org.omg.CORBA_2_3.ORB)_orb;
        orb23.register_value_factory(vfact.type_id(), vfact.value_factory());
    }

    final public org.omg.CORBA.portable.ValueFactory
    get_valuefactory(String type_id)
    {
        org.omg.CORBA_2_3.ORB orb23 = (org.omg.CORBA_2_3.ORB)_orb;
        return orb23.lookup_value_factory(type_id);
    }

    final public org.omg.CORBA.Object
    resolve_initial_references(String name)
    {
        // first check the ORBService internal storage
        org.omg.CORBA.Object res = (org.omg.CORBA.Object)_initial_references.get(name);
        if (res!=null) {
            return res;
        }

        // else ask the ORB itself
        try {
            return _orb.resolve_initial_references(name);
        } catch (Exception ex) {
            final String opname = "resolve_initial_references";
            TheLogger.debug(_class_name, opname, "IGNORE", ex);
            return null;
        }
    }

    final public void
    register_initial_references(String name, org.omg.CORBA.Object ref)
    {
        _initial_references.put(name, ref);
    }

    final public String[]
    list_initial_references()
    {
        // NOTE: how do we obtain init ref from the ORB ??
        // TODO

        return (String[])_initial_references.keySet().toArray(new String[0]);
    }
}
