// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.runtime;

/**
 **  <p>Default implementation of the <tt>RegistrationService</tt> system service.</p>
 **/
public class RegistrationServiceImpl
extends org.omg.CORBA.LocalObject
implements RegistrationService
{
    // registration service
    static final private String _class_name = "RegistrationServiceImpl";
    static final private String _service_id = RegistrationService.SERVICE_ID;
    private java.util.HashMap _schemes;

    // default constructor
    protected
    RegistrationServiceImpl()
    {
        // registration service
        _schemes = null;
    }

    //
    //  entry point
    //

    static public SystemService
    create_service()
    {
        return new RegistrationServiceImpl();
    }

    //
    //  IDL:objectweb.org/corba/runtime/SystemComponent:1.0
    //

    final public void
    system_configuration_complete(SystemConfiguration cfg)
    {
        _schemes = new java.util.HashMap();

        // add default schemes: FileRegistrationScheme and INSRegistrationScheme
        _schemes.put(FileRegistrationScheme.SCHEME_ID, new FileRegistrationSchemeImpl());
        _schemes.put(INSRegistrationScheme.SCHEME_ID, new INSRegistrationSchemeImpl());
    }

    final public void
    destroy()
    {
        _schemes.clear();
    }

    //
    //  IDL:objectweb.org/corba/runtime/SystemService:1.0
    //

    final public String
    service_id()
    {
        return _service_id;
    }

    //
    //  IDL:objectweb.org/corba/runtime/RegistrationService:1.0
    //

    final public void
    add_scheme(String location, String entrypt)
    {
        // check if location is set
        if (location!=null) { 
            // add archive location to class loader
            TheClassLoader.addResource(location);
        }

        // create the scheme
        RegistrationScheme scheme = (RegistrationScheme)TheClassLoader.newInstance(entrypt);

        // check if created
        if (scheme==null) {
            // NOTE: TODO: should be reported as an exception
            final String opname = "add_scheme";
            final String msg = "IGNORE (scheme not created)";
            TheLogger.debug(_class_name, opname, msg);
        }

        // add
        _schemes.put(scheme.scheme_id(), scheme);
    }


    final public RegistrationScheme
    get_scheme(String scheme_id)
    {
        return (RegistrationScheme)_schemes.get(scheme_id);
    }
}
