// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.logservice;

import org.objectweb.corba.runtime.*;

/**
 **  <p>Implementation of the <tt>PortableInterceptor::ORBInitializer</tt> ECM interface
 **  for the ECM log service.</p>
 **/
public class LogORBInitializerImpl
extends org.omg.CORBA.LocalObject
implements org.omg.PortableInterceptor.ORBInitializer
{
    public
    LogORBInitializerImpl()
    {
    }

    //
    //  IDL:omg.org/PortableInterceptor/ORBInitializer:1.0
    //

    final public void
    pre_init(org.omg.PortableInterceptor.ORBInitInfo info)
    {
    }

    final public void
    post_init(org.omg.PortableInterceptor.ORBInitInfo info)
    {
        // create IOP 1.2 codec
        org.omg.IOP.Encoding enc = new org.omg.IOP.Encoding();
        enc.format = org.omg.IOP.ENCODING_CDR_ENCAPS.value;
        enc.major_version = (byte)1;
        enc.minor_version = (byte)2;

        org.omg.IOP.CodecFactory fact = null;
        org.omg.IOP.Codec codec = null;

        fact = info.codec_factory();

        try {
            codec = fact.create_codec(enc);
        } catch (org.omg.IOP.CodecFactoryPackage.UnknownEncoding ex) {
            return ;
        }

        // allocate slot
        int slot = info.allocate_slot_id();

        // register Log current
        LogCurrentImpl logcurrent = new LogCurrentImpl(slot, info.orb_id());
        try {
            info.register_initial_reference(LOG_CURRENT_ID.value, logcurrent);
        } catch (org.omg.PortableInterceptor.ORBInitInfoPackage.InvalidName ex) {
            throw new java.lang.Error(ex.getMessage());
        }

        // register log CRI and SRI
        try {
            info.add_client_request_interceptor(new LogCRIImpl(codec, slot));
            info.add_server_request_interceptor(new LogSRIImpl(codec, slot));
        } catch (org.omg.PortableInterceptor.ORBInitInfoPackage.DuplicateName ex) {
            throw new java.lang.Error(ex.getMessage());
        }
    }
}
