// ====================================================================
// 
//   ECM: The Extensible Container Model
//   Copyright (C) 2004 THALES
//   Contact: openccm-ecm@objectweb.org
//
//   This library is free software; you can redistribute it and/or
//   modify it under the terms of the GNU Lesser General Public
//   License as published by the Free Software Foundation; either
//   version 2.1 of the License, or any later version.
//
//   This library is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
//   Lesser General Public License for more details.
//
//   You should have received a copy of the GNU Lesser General Public
//   License along with this library; if not, write to the Free Software
//   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
//   USA
//
//   Initial developer(s): Mathieu Vadet.
//   Initial Funding: IST COACH European project (IST-2001-34445)
//                    http://www.ist-coach.org 
//
// ====================================================================



package org.objectweb.corba.logservice;

import org.objectweb.corba.runtime.*;

/**
 **  <p>This class implements a server request interceptor for the log service.
 **  This SRI extract the propagated 'id' information and place it in the current.</p>
 **
 **  @see org.objectweb.corba.logservice.LogCurrentImpl LogCurrentImpl
 **  @see org.objectweb.corba.logservice.LogCRIImpl LogCRIImpl
 **/
public class LogSRIImpl
extends org.omg.CORBA.LocalObject
implements org.omg.PortableInterceptor.ServerRequestInterceptor
{
    //
    private org.omg.IOP.Codec _codec;
    private int _slot_id;

    public
    LogSRIImpl(org.omg.IOP.Codec codec,
               int slotid)
    {
        _codec = codec;
        _slot_id = slotid;
    }

    //
    //  internal operations
    //

    private void
    setIdInServiceContext(org.omg.PortableInterceptor.ServerRequestInfo info)
    {
        // get server id from slot
        org.omg.CORBA.Any cid = null;
        try {
            cid = info.get_slot(_slot_id);
        } catch (org.omg.PortableInterceptor.InvalidSlot ex) {
        }

        if (cid==null) {
            // TODO: change
            return ;
        }

        // set server id in service context
        org.omg.IOP.ServiceContext sctx = new org.omg.IOP.ServiceContext();
        sctx.context_id = LOG_IOP_SERVICE_ID.value;
        try {
            sctx.context_data = _codec.encode(cid);
        } catch (org.omg.IOP.CodecPackage.InvalidTypeForEncoding ex) {
        }

        info.add_reply_service_context(sctx, true);
    }

    //
    //  IDL:omg.org/PortableInterceptor/RequestInterceptor:1.0
    //

    final public String
    name()
    {
        return "LogSRIImpl";
    }

    final public void
    destroy()
    {
        _codec = null;
    }

    //
    //  IDL:omg.org/PortableInterceptor/ServerRequestInterceptor:1.0
    //

    final public void
    receive_request_service_contexts(org.omg.PortableInterceptor.ServerRequestInfo info)
    throws org.omg.PortableInterceptor.ForwardRequest
    {
        System.err.println("### LogSRIImpl::receive_request_service_contexts called");
        // get log service context
        org.omg.IOP.ServiceContext sctx = null;
        try {
            sctx = info.get_request_service_context(LOG_IOP_SERVICE_ID.value);
        } catch (org.omg.CORBA.SystemException ex) {
            System.err.println("!!! LogSRIImpl::receive_request_service_contexts: Service context not found");
        }

        if (sctx==null) {
            System.err.println("!!! LogSRIImpl::receive_request_service_contexts: Service context not found");
            return ;
        }

        // extract client id from context
        org.omg.CORBA.Any cid = null;
        try {
            cid = _codec.decode(sctx.context_data);
        } catch (org.omg.IOP.CodecPackage.FormatMismatch ex) {
        }

        // set client id in slot
        try {
            info.set_slot(_slot_id, cid);
        } catch (org.omg.PortableInterceptor.InvalidSlot ex) {
        }
   }

    final public void
    receive_request(org.omg.PortableInterceptor.ServerRequestInfo info)
    throws org.omg.PortableInterceptor.ForwardRequest
    {
        System.err.println("### LogSRIImpl::receive_request called on operation: "+info.operation());
    }

    final public void
    send_reply(org.omg.PortableInterceptor.ServerRequestInfo info)
    {
        System.err.println("### LogSRIImpl::send_reply called on operation: "+info.operation());
        // insert the server id in the reply
        setIdInServiceContext(info);
    }

    final public void
    send_exception(org.omg.PortableInterceptor.ServerRequestInfo info)
    throws org.omg.PortableInterceptor.ForwardRequest
    {
        System.err.println("### LogSRIImpl::send_exception called on operation: "+info.operation());
        // insert the server id in the reply
        setIdInServiceContext(info);
    }

    final public void
    send_other(org.omg.PortableInterceptor.ServerRequestInfo info)
    throws org.omg.PortableInterceptor.ForwardRequest
    {
        System.err.println("### LogSRIImpl::send_other called on operation: "+info.operation());
        // insert the server id in the reply
        setIdInServiceContext(info);
    }
}
